pub struct GeoscienceModel {
pub physics: Physics,
pub domain: Domain,
pub materials: HashMap<String, Option<Material>>,
}Fields
physics: Physicsdomain: Domainmaterials: HashMap<String, Option<Material>>Trait Implementations
Sourceimpl Clone for GeoscienceModel
impl Clone for GeoscienceModel
Sourcefn clone(&self) -> GeoscienceModel
fn clone(&self) -> GeoscienceModel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GeoscienceModel
impl Debug for GeoscienceModel
Sourceimpl<'de> Deserialize<'de> for GeoscienceModel
impl<'de> Deserialize<'de> for GeoscienceModel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromStr for GeoscienceModel
impl FromStr for GeoscienceModel
Sourceimpl JsonSchema for GeoscienceModel
impl JsonSchema for GeoscienceModel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GeoscienceModel
impl PartialEq for GeoscienceModel
Sourceimpl Serialize for GeoscienceModel
impl Serialize for GeoscienceModel
impl StructuralPartialEq for GeoscienceModel